@@ -1,13 +1,11 @@
 #!/bin/bash
 
-publish=false
 PACKAGE="transparentpath"
 VERSION="3"
 COMMAND="install"
 
 while true; do
   case "$1" in
-    -p | --publish) publish=true ; shift 1 ;;
     -v) VERSION=$2 ; shift 2 ;;
     -c) COMMAND=$2 ; shift 2 ;;
     -- ) shift; break ;;
@@ -34,9 +32,6 @@ fi
 pip3 uninstall "$PACKAGE" -y
 pip3 install setuptools
 python$VERSION setup.py $COMMAND
-if $publish && [ -f "$HOME/bin/gspip" ] ; then
-  gspip push -s "  "
-fi
 if [ -d "dist" ] && [ "$COMMAND" != "sdist" ] ; then rm -r dist ; fi
 if [ -d "build" ] ; then rm -r build ; fi
 if ls "$PACKAGE".egg-info* &> /dev/null ; then rm -r "$PACKAGE".egg-info* ; fi
